#
# spec file for package python-mailman
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global aiosmtpd_min_version 1.4.3
# normally it would be 1.6.2,!=1.7.0 but to avoid super comlex constructs in the spec file ... lets go with the version that we have in TW
%global alembic_min_version 1.12
%global authheaders_min_version 0.16
%global authres_min_version 1.0.1
%global click_min_version 8.0.0
%global dnspython_min_version 1.14.0
%global falcon_min_version 3.1.3
%global flufl_bounce_min_version 4.0
%global flufl_i18n_min_version 3.2
%global flufl_lock_min_version 5.1
%global python_dateutil_min_version 2.0
%global sqlalchemy_min_version 1.4.0
%global zope_interface_min_version 5.0

%define mailman_name     mailman
%define mailman_homedir  %{_localstatedir}/lib/%{mailman_name}
%define mailman_logdir   %{_localstatedir}/log/%{mailman_name}
%define mailman_spooldir %{_localstatedir}/spool/%{mailman_name}
%define mailman_rundir   %{_rundir}/%{mailman_name}
%define mailman_lockdir  %{_rundir}/lock/%{mailman_name}
%global mailman_services %{mailman_name}.service %{mailman_name}-digests.service %{mailman_name}-digests.timer %{mailman_name}-notify.service %{mailman_name}-notify.timer

%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
# Keep this in sync with HyperKitty und Postorius
# Always only build one flavor: primary python for TW, python311 from the SLE15 python module for 15.x
%if 0%{?suse_version} >= 1550
%define pythons python3
%else
%{?sle15_python_module_pythons}
%endif
%global mypython %pythons
%global mypython_sitelib %{expand:%%{%{mypython}_sitelib}}
%define plainpython python

Name:           python-mailman%{psuffix}
Version:        3.3.10
Release:        2.1
Summary:        A Mailing List Manager
Group:          Productivity/Networking/Email/Mailinglists
License:        GPL-3.0-only
URL:            https://www.list.org
Source0:        https://gitlab.com/mailman/mailman/-/releases/v%{version}/downloads/mailman-%{version}.tar.gz
Source1:        https://gitlab.com/mailman/mailman/-/releases/v%{version}/downloads/mailman-%{version}.tar.gz.asc
Source2:        python-mailman.keyring
#
Source10:       mailman.cfg
Source11:       mailman.service
Source12:       mailman-tmpfiles.conf
Source13:       mailman.logrotate
Source14:       mailman-user.conf
#
Source20:       mailman-digests.service
Source21:       mailman-digests.timer
Source22:       mailman-notify.service
Source23:       mailman-notify.timer
#
Source30:       README.SUSE.md
Source31:       python-mailman.rpmlintrc
#
# PATCH-FIX-UPSTREAM mailman-fix-python-313-posixpath.patch https://gitlab.com/mailman/mailman/-/commit/685d9a7bdbd382d9e8d4a2da74bd973e93356e05.patch
Patch0:         mailman-fix-python-313-posixpath.patch
#
BuildRequires:  %{python_module pdm}
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  sysuser-tools
%if 0%{?suse_version} >= 1550
# use the real python3 primary for rpm pythondistdeps.py
BuildRequires:  python3-packaging
%endif
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module flufl.testing}
BuildRequires:  %{python_module nose2}
BuildRequires:  %{python_module pytest}
BuildRequires:  (mailman3 = %{version} with %mypython-mailman3)
%endif

%description
Mailman is a mailing list manager from the GNU project.

%package -n mailman3
Summary:        A mailing list manager
Requires:       %{mypython}-SQLAlchemy >= %{sqlalchemy_min_version}
Requires:       %{mypython}-aiosmtpd >= %{aiosmtpd_min_version}
Requires:       %{mypython}-alembic >= %{alembic_min_version}
Requires:       %{mypython}-atpublic
Requires:       %{mypython}-authheaders >= %{authheaders_min_version}
Requires:       %{mypython}-authres >= %{authres_min_version}
Requires:       %{mypython}-click >= %{click_min_version}
Requires:       %{mypython}-dnspython >= %{dnspython_min_version}
Requires:       %{mypython}-falcon >= %{falcon_min_version}
Requires:       %{mypython}-flufl.bounce >= %{flufl_bounce_min_version}
Requires:       %{mypython}-flufl.i18n >= %{flufl_i18n_min_version}
Requires:       %{mypython}-flufl.lock >= %{flufl_lock_min_version}
Requires:       %{mypython}-gunicorn
Requires:       %{mypython}-lazr.config
Requires:       %{mypython}-passlib
Requires:       %{mypython}-psycopg2
Requires:       %{mypython}-python-dateutil >= %{python_dateutil_min_version}
Requires:       %{mypython}-requests
Requires:       %{mypython}-zope.component
Requires:       %{mypython}-zope.configuration
Requires:       %{mypython}-zope.event
Requires:       %{mypython}-zope.interface >= %{zope_interface_min_version}
%if %{python_version_nodots} >= 313
Requires:       %{mypython}-standard-nntplib
%endif
Requires:       logrotate
Requires(pre):  /usr/sbin/groupadd
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       mailman = %{version}
# help in replacing any previously installed flavor package back to the unprefixed package
%if 0%{?suse_version} < 1550
Requires:       %{mypython}-importlib-resources >= 1.1.0
Obsoletes:      python3-mailman < %{version}-%{release}
Obsoletes:      python3-mailman3 < %{version}-%{release}
%endif
Provides:       %{mypython}-mailman = %{version}-%{release}
Obsoletes:      %{mypython}-mailman < %{version}-%{release}
Provides:       %{mypython}-mailman3 = %{version}-%{release}
Obsoletes:      %{mypython}-mailman3 < %{version}-%{release}

%description -n mailman3
Mailman is a mailing list manager from the GNU project.

%package -n system-user-%{mailman_name}
Summary:        System user and group mailman
Requires(pre):  group(lock)
Requires(pre):  group(mail)
%sysusers_requires

%description -n system-user-%{mailman_name}
System user for use by the mailman client.

%prep
%autosetup -p1 -n mailman-%{version}

# README.SUSE.md
cp %{SOURCE30} .

%build
sed -i 's:/sbin:%{_prefix}/bin:' src/mailman/config/mailman.cfg

%pyproject_wheel
./generate_mo.sh

%sysusers_generate_pre %{SOURCE14} mailman system-user-%{mailman_name}.conf

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

install -d -m 0755 \
            %{buildroot}%{_sysconfdir} \
            %{buildroot}%{_sysconfdir}/%{mailman_name}.d \
            %{buildroot}%{_tmpfilesdir} \
            %{buildroot}%{_sbindir} \
            %{buildroot}%{_unitdir} \
            %{buildroot}%{mailman_homedir} \
            %{buildroot}%{mailman_homedir}/data \
            %{buildroot}%{mailman_rundir} \
            %{buildroot}%{mailman_lockdir} \
            %{buildroot}%{mailman_logdir} \
            %{buildroot}%{mailman_spooldir}

%if 0%{?suse_version} > 1500
install -d -m 0755  %{buildroot}%{_distconfdir}/logrotate.d
install -m 0644 %{SOURCE13} %{buildroot}%{_distconfdir}/logrotate.d/%{mailman_name}
sed -i 's,@LOGDIR@,%{mailman_logdir},g;s,@BINDIR@,%{_bindir},g' \
        %{buildroot}%{_distconfdir}/logrotate.d/%{mailman_name}
%else
install -d -m 0755  %{buildroot}%{_sysconfdir}/logrotate.d
install -m 0644 %{SOURCE13} %{buildroot}%{_sysconfdir}/logrotate.d/%{mailman_name}
sed -i 's,@LOGDIR@,%{mailman_logdir},g;s,@BINDIR@,%{_bindir},g' \
        %{buildroot}%{_sysconfdir}/logrotate.d/%{mailman_name}
%endif

install -m 0640 %{SOURCE10} %{buildroot}%{_sysconfdir}/%{mailman_name}.cfg
install -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/%{mailman_name}.service
install -m 0644 %{SOURCE12} %{buildroot}%{_tmpfilesdir}/%{mailman_name}.conf

install -D -m 0644 %{SOURCE14} %{buildroot}%{_sysusersdir}/system-user-%{mailman_name}.conf

install -m 0644 %{SOURCE20} %{buildroot}%{_unitdir}/%{mailman_name}-digests.service
install -m 0644 %{SOURCE21} %{buildroot}%{_unitdir}/%{mailman_name}-digests.timer
install -m 0644 %{SOURCE22} %{buildroot}%{_unitdir}/%{mailman_name}-notify.service
install -m 0644 %{SOURCE23} %{buildroot}%{_unitdir}/%{mailman_name}-notify.timer

ln -s /sbin/service %{buildroot}%{_sbindir}/rc%{mailman_name}
ln -s /sbin/service %{buildroot}%{_sbindir}/rc%{mailman_name}-digests
ln -s /sbin/service %{buildroot}%{_sbindir}/rc%{mailman_name}-notify

%endif

%check
%if %{with test}
export LANG=C.UTF-8
%if 0%{?suse_version} <= 1500
# mailman.rest.tests.test_wsgiapp.TestSupportedContentType
# AssertionError: 'application/json; charset=UTF-8' != 'application/json'
rm src/mailman/rest/tests/test_wsgiapp.py
%endif
# doctest fails miserably
find -name '*.rst' -exec rm {} \;
# used to have ports 902{4,5}
rm src/mailman/mta/tests/test_aliases.py
# PermissionError: [Errno 13] Permission denied: '/usr/bin/master'
rm src/mailman/core/tests/test_logging.py
# PermissionError: [Errno 13] Permission denied: '/usr/bin/master'
rm src/mailman/commands/tests/test_cli_control.py
# do not use well known ports 9024 and 9025
sed -i "s:\(902\):4\1:" src/mailman/testing/testing.cfg
# https://gitlab.com/mailman/mailman/-/issues/1125
rm src/mailman/handlers/tests/test_avoid_duplicates.py
# Looks like this is racy, https://gitlab.com/mailman/mailman/-/issues/1236
rm src/mailman/commands/tests/test_cli_syncmembers.py
#
%python_exec -m nose2 -v
%endif

%if !%{with test}
%pre -n system-user-%{mailman_name} -f mailman.pre

%pre -n mailman3
%service_add_pre %{mailman_services}
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/etc; save any old .rpmsave
for i in logrotate.d/%{mailman_name} ; do
   test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done
%endif

%if 0%{?suse_version} > 1500
%posttrans  -n mailman3
# Migration to /usr/etc, restore just created .rpmsave
for i in logrotate.d/%{mailman_name} ; do
   test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%post -n mailman3
%tmpfiles_create %{_tmpfilesdir}/%{mailman_name}.conf
%service_add_post %{mailman_services}

%preun -n mailman3
%service_del_preun %{mailman_services}

%postun -n mailman3
%service_del_postun %{mailman_services}

%files -n mailman3
%doc README.md README.SUSE.md src/mailman/docs/NEWS.rst
%license COPYING
%{_sbindir}/rc%{mailman_name}*
%{_bindir}/runner
%{_bindir}/mailman
%{_bindir}/master
%{mypython_sitelib}/mailman
%{mypython_sitelib}/mailman-%{version}*-info
%{_unitdir}/%{mailman_name}.service
%{_unitdir}/%{mailman_name}-digests.service
%{_unitdir}/%{mailman_name}-digests.timer
%{_unitdir}/%{mailman_name}-notify.service
%{_unitdir}/%{mailman_name}-notify.timer
%{_tmpfilesdir}/%{mailman_name}.conf
%config(noreplace) %attr(640,root,mailman) %{_sysconfdir}/mailman.cfg
%if 0%{?suse_version} > 1500
%{_distconfdir}/logrotate.d/%{mailman_name}
%else
%config(noreplace) %{_sysconfdir}/logrotate.d/%{mailman_name}
%endif
%dir %attr(750,root,mailman) %{_sysconfdir}/%{mailman_name}.d
%dir %attr(750,mailman,mailman) %{mailman_homedir}
%dir %attr(770,mailman,mail) %{mailman_homedir}/data
%dir %attr(750,mailman,mailman) %{mailman_spooldir}
%dir %attr(750,mailman,mailman) %{mailman_logdir}
%ghost %dir %{mailman_rundir}
%ghost %dir %{_rundir}/lock
%ghost %dir %{mailman_lockdir}

%files -n system-user-%{mailman_name}
%{_sysusersdir}/system-user-%{mailman_name}.conf
%endif

%changelog
* Tue Jul 15 2025 Andreas Schneider <asn@cryptomilk.org>
- Fix removal of context manager usage for PosixPath in Python 3.13
- Added mailman-fix-python-313-posixpath.patch
- Removed racy test_cli_syncmembers.py from tests
* Tue Jul 15 2025 Andreas Schneider <asn@cryptomilk.org>
- Require python-standard-nntplib for Python >= 3.13
* Mon Jul 14 2025 Andreas Schneider <asn@cryptomilk.org>
- Fix CVE-2025-53882 (boo#1246467)
* Wed Oct  2 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.3.10
  * See https://gitlab.com/mailman/mailman/-/blob/v3.3.10/src/mailman/docs/NEWS.rst
    or the file NEWS.rst in this package
* Wed Sep 25 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.3.10b2
  * See https://gitlab.com/mailman/mailman/-/blob/v3.3.10b2/src/mailman/docs/NEWS.rst
    or the file NEWS.rst in this package
* Sun Sep 22 2024 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.3.10b1
  * See https://gitlab.com/mailman/mailman/-/blob/v3.3.10b1/src/mailman/docs/NEWS.rst
    or the file NEWS.rst in this package
- Removed find-flufl.patch
* Thu Feb 29 2024 Benjamin Greiner <code@bnavigator.de>
- Simplify python flavor selection
  * Go back to primary python3 on Tumbleweed
  * Use SLE15 python module pythons on 15.x
* Thu Feb 15 2024 Markéta Machová <mmachova@suse.com>
- Adapt to new RPM 4.19 and properly create mailman user/group (boo#1219674)
- Build on Python 3.12 for the Factory
* Tue Jan 23 2024 Markéta Machová <mmachova@suse.com>
- Add patch find-flufl.patch to fix the tests with recent flufl.*
- Don't require importlib-resources on new Pythons, they are already
  a part of a standard library
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- make it easier to notice to keep buildrequires and runtime
  requires version limits in sync. This will also help us to notice
  early when the version of other libraries do not match the
  requires encoded in the source code.
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Require authheaders >= 0.15.2
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.3.9
  * See https://gitlab.com/mailman/mailman/-/blob/v3.3.9/src/mailman/docs/NEWS.rst
    or the file NEWS.rst in this package
- Removed mailman-fix-importlib-resources.patch
* Thu Sep 21 2023 Andreas Schneider <asn@cryptomilk.org>
- Add missing Pre-require for groupadd
* Fri Aug 18 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix issues with importlib_resources for Python 3.11
  * Added mailman-fix-importlib-resources.patch
* Sat Jul  1 2023 Andreas Schneider <asn@cryptomilk.org>
- Add missing require for psycopg2
* Wed Jun  7 2023 Andreas Schneider <asn@cryptomilk.org>
- Move mailman to Python 3.11 on TW and Leap 15.5
* Wed Jun  7 2023 Andreas Schneider <asn@cryptomilk.org>
- Allow the mailman group to write to the data directory
  * This will hold the postfix database for the domains and we need
    to be able to write to it as the postfix user (member of mailman group).
* Thu Mar 30 2023 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Compile and include .mo files, used by _() strings
* Mon Feb  6 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.3.8:
  * The deprecated SQLAlchemy query.values() method is replaced by
    query.with_entities(). This fixes an issue with MariaDB that truncated
    the generated postfix_lmtp file. (Closes #1044)
  * An uncaught passlib.exc.UnknownHashError in utilities/passwords.py is
    now caught and handled appropriately. (Closes #1046)
  * Rejection notices for a message with an RFC 2047 encoded Subject: now
    display the decoded subject. (Closes #672)
  * Don't RFC 2047 encode display names in UserNotifications. Allow sending
    utf-8 encoded notifications. (Closes #673)
  * Don't replace non-ascii in subjects in notifications. (Closes #673)
  * The mailman members command no longer RFC 2047 encodes non-ascii display
    names. (Closes #1048)
  * Improve the performance of Held message handling by reducing the total
    number of database calls required. (Fixes #1026 and #1045)
  * Add support for Python 3.10. (Closes #936)
  * Add support for Python 3.11 (See !1076)
  * Add support for SQLAlchemy 1.4+ (Closes #964)
  * Drop support for Python 3.6 since SQLAlchemy 2.0 will drop support for
    it and it is EOL by now. (See !1035)
  * The fix for #994 in 3.3.6 blocked too many subscription attempts. This is
    now corrected and another test added.
- Drop patches now included upstream:
  * mailman-support-sqlalchemy-1-4.patch
  * python-mailman-test_interact_default_banner.patch
  * support-alembic-1-8.patch
  * support-attrs-22.patch
  * support-sqlalchemy-1-4.patch
* Wed Dec 14 2022 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Fix timers target to avoid systemd ordering cycle
* Tue Nov  1 2022 Andreas Schneider <asn@cryptomilk.org>
- Bump version requirement for python3-authheaders
* Thu Oct 27 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 3.3.6
  * https://gitlab.com/mailman/mailman/-/blob/3.3.6/src/mailman/docs/NEWS.rst
- Added support-attrs-22.patch
- Removed ARC-message-fail-tests.patch
* Tue Sep 27 2022 Markéta Machová <mmachova@suse.com>
- Rewrite support-sqlalchemy-1-4.patch
  * to be indeed backward-compatible
  * to reflect newer mailman-support-sqlalchemy-1-4.patch
* Wed Aug 31 2022 Stefan Schubert <schubi@suse.com>
- Moved logrotate files from user specific directory /etc/logrotate.d
  to vendor specific directory /usr/etc/logrotate.d.
* Mon Jul  4 2022 Ben Greiner <code@bnavigator.de>
- Go back to Python 3.9 for mailman. Python 3.10 is not supported
  and it is unclear whether the test failures are due to the
  production code or only in the setup of aiosmtpd in the test
  suite. -- https://gitlab.com/mailman/mailman/-/issues/936
* Wed Jun 29 2022 Lars Vogdt <lars@linux-schulserver.de>
- added mailman-support-sqlalchemy-1-4.patch (from Andreas Schneider):
  The TypeDecorator.cache_ok class-level flag indicates if this custom
  TypeDecorator is safe to be used as part of a cache key. This flag defaults to
  None which will initially generate a warning when the SQL compiler attempts to
  generate a cache key for a statement that uses this type. If the TypeDecorator
  is not guaranteed to produce the same bind/result behavior and SQL generation
  every time, this flag should be set to False; otherwise if the class produces
  the same behavior each time, it may be set to True. See TypeDecorator.cache_ok
  for further notes on how this works.
* Mon Jun 13 2022 Andreas Schneider <asn@cryptomilk.org>
- Added support-alembic-1-8.patch
- Removed support-alembic-1-7.patch
* Mon Feb 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Clean up a half-completed migration away from python-rpm-macros.
  As a consequence, mailman3 now pulls in all dependencies again.
* Thu Jan 20 2022 pgajdos@suse.com
- fix obsoletes
* Wed Jan 19 2022 Matej Cepl <mcepl@suse.com>
- Add patch ARC-message-fail-tests.patch which allows four tests
  to pass with different format of the output.
* Tue Jan 18 2022 pgajdos@suse.com
- rename python3-mailman package to mailman3 [bsc#1194497]
* Wed Nov 17 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to 3.3.5, which provides many bug fixes and also these new features:
  - There is a new bounce_notify_admin_on_bounce_increment list
    setting and a corresponding list:admin:notice:increment
    template for the notice. This setting, if True, will cause a
    notice to be sent to the list admins when a member's bounce
    score is incremented, but doesn't disable delivery.
  - There is a new moderator_request_life setting in the
    [mailman] section of mailman.cfg that controls the lifetime
    of pending moderator requests as opposed to pending user
    confirmations.  Default is 180 days.
  - There is a new task runner to do periodic tasks.  The current
    implementation evicts expired pendings and cache entries
    and removes orphaned workflows and orphaned message store
    messages.  It does these tasks at intervals defined by the
    new run_tasks_every setting in the [mailman] section of
    mailman.cfg. Default is 1 hour.
  - There is a new list:admin:notice:pending template for the
    notice from the mailman notify command.
  - The nntp runner will now run the gatenews subcommand at
    intervals defined by a new gatenews_every setting in the
    [nntp] section of mailman.cfg. Default is 5 every minutes.
  - Check the REST API password in a way that is resistant to
    timing attacks. (CVE-2021-34337)
- Added support-alembic-1-7.patch
- Removed obsolete support-click-8-0.patch
- Added rpmlintrc
* Fri Jul 30 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add support-click-8-0.patch:
  * Lightly rebased from upstream to support click 8.0
- Add support-sqlalchemy-1-4.patch:
  * Support running with SQLAlchemy 1.4
* Tue May  4 2021 Ben Greiner <code@bnavigator.de>
- Restrict build to primary python3 in order to avoid conflicting
  packages.
* Mon Mar 22 2021 Michael Ströder <michael@stroeder.com>
- dropped obsolete gl823_exclude_failing_tests.patch
- Update to 3.3.4
  * Bugs
  * Require aiosmtpd >= 1.4.1 to allow address local parts longer than 64 bytes
    in the lmtp runner.  (Closes #836)
  * The email join command now honors the digest=<no|mime|plain> option.
    (Closes #19)
  * Folded ``Message-ID`` headers no longer cause folded smtp.log messages.
    (Closes #844)
  * Removal of headers from posts to anonymous lists that can reveal the poster
    or the poster's domain has been improved.  (Closes #848)
  * Command line
  * The ``notify`` subcommand will now decode an RFC 2047 encoded Subject: for
    the report of held messages.  (Closes #831)
  * The deprecated options ``--add``, ``--del`` and ``--sync`` are now disabled
    on the ``mailman members`` command.
  * REST
  * Improve the speed of Members lookup via REST API. (Related to #700)
  * Allow specifying ``delivery_mode`` and ``delivery_status`` when creating a
    new Member. (Closes #828)
  * Allow filtering members in ``/members/find`` API using ``delivery_status``,
    ``delivery_mode`` and ``moderation_action``. (See #827)
  * New Features
  * There is a new setting ``filter_report`` in the ``[mailman]`` section of
    mailman.cfg.  If this is set to ``yes``, a report of changes by content
    filtering will be added to the outgoing message.  (Closes #833)
  * There is a new setting ``check_max_size_on_filtered_message`` in the
    ``[mailman]`` section of mailman.cfg.  If this is set to ``yes`` and the
    list does content filtering, the ``max_message_size`` hold will be based
    on the size of the content filtered message.  (Closes #377)
  * There is a new setting ``anonymous_list_keep_headers`` in the ``[mailman]``
    section of mailman.cfg.  This is part of improved removal of headers from
    posts to anonymous lists.  This setting is a space separated list of regexp
    patterns.  After anonomyzing removes the headers which are known to reveal
    the poster or poster's domain, it then removes all headers whose names do
    not match (case-insensitively) one of these patterns.  The default setting
    keeps non X- headers, those X- headers added by Mailman and any X-Spam-
    headers.
* Thu Feb  4 2021 Matej Cepl <mcepl@suse.com>
- Add gl823_exclude_failing_tests.patch to skip two failing tests
  (gl#mailman/mailman#823).
* Wed Feb  3 2021 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile. Update summary so it does not fall under
  rpmlint name-repeated-in-summary.
* Wed Feb  3 2021 Andreas Schneider <asn@cryptomilk.org>
- Fix building on tumbleweed
* Wed Feb  3 2021 Michael Ströder <michael@stroeder.com>
- Update to 3.3.3:
  * Handle some UnicodeEncodeErrors in creating digests.  (Closes #560)
  * Increased the size of the data column in the workflowstate table.
    (Closes #793)
  * Implemented a ``scrubber`` for plain text digests.  (Closes #473)
  * The ``mailman gatenews`` command now adds ``original_size`` as a message
    attribute.  (Extends fix for #762)
  * Handle FileNotFoundError when creating digest.mmdf file without a
    parent directory present.  (Closes #699)
  * Fixed an issue where content filtering can throw UnicodeEncodeError when
    converting HTML to plain text.  (Closes #798)
  * A bounce for a non-existent list is now handled.  (Closes #799)
  * RFC 2047 From: headers in emailed ``join`` commands are now decoded.
    (Closes #802)
  * The ``mailman addmembers`` command now catches and reports a
    ``SubscriptionPendingError``.  (Closes #805)
  * RFC 2369 ``List-Owner`` header is now added when these headers are included.
    (Closes #809)
  * Header filters will now properly match RFC 2047 encoded headers.
    (Closes #815)
  * Mailman's ``vette`` log discard messages now include the reasons.
    (Closes #816)
  * Increase the default REST API (gunicorn) timeout to 360 seconds from 30 as
    several API endpoinds can be very slow. (Closes #770)
  * Header filter rules are now properly processed after deletions and/or
    reordering.  (Closes #818)
  * Folded ``To: list-confirm+token@...`` headers are now parsed correctly.
    (Closes: #819)
* Tue Dec 15 2020 Andreas Schneider <asn@cryptomilk.org>
- Added mailman-notify.service and mailman-notify.timer
- Added rcmailman* service symlinks
- Added missing logrotate requirement
* Tue Dec 15 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix systemd services
* Tue Dec 15 2020 Andreas Schneider <asn@cryptomilk.org>
- Add missing services and timers to systemd
* Sat Nov 28 2020 Michael Ströder <michael@stroeder.com>
- Update to 3.3.2:
  * Support for inviting users to join mailing lists.
  * New adddmembers, delmembers and syncmembers command to
    manage membership from CLI.
  * Addition of new REST API endpoints that return the count of held messages
    and subscription requests of much faster page loads in Postorius.
  * Addition of support for filtering in some API endpoints like Members
    and Subscription requests.
  * Support for address= option in email join command to subscribe an address
    other then sending address.
  * Addition of who email command to lookup memberships.
  * Expose emergency field for MailingList resource in REST API.
  * Several bug fixes to support new major version of libraries like dnspython,
    flufl.* etc.
* Wed Oct  7 2020 Andreas Schneider <asn@cryptomilk.org>
- Remove suid bit from /var/lib/mailman/data
* Wed Sep 30 2020 pgajdos@suse.com
- remove systemd (build)requires
* Sat Sep 26 2020 Andreas Schneider <asn@cryptomilk.org>
- Create mailman user and group
- Create directories for mailman and use FHS directory layout
- Create initial /etc/mailman.cfg
- Create /etc/mailman.d/ directory for extensions
- Add systemd files
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Apr 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.1:
  * No obvious changelog
* Thu Jan 23 2020 pgajdos@suse.com
- do not require python-cffi, it will be required by
  python-PyNaCl
* Tue Jan 14 2020 pgajdos@suse.com
- be able to run test on 15
* Tue Dec 10 2019 pgajdos@suse.com
- disable src/mailman/commands/tests/test_cli_create.py
  https://gitlab.com/mailman/mailman/issues/654
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Mon Dec  2 2019 pgajdos@suse.com
- requires setuptools
* Wed Nov 20 2019 pgajdos@suse.com
- /usr/sbin instead of /sbin in mailman.cfg
* Tue Nov  5 2019 pgajdos@suse.com
- run the testsuite
* Tue Sep 24 2019 pgajdos@suse.com
- initial version 3.3.0 [SLE-7686]
